#
# spec file for package adns
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libadns1
Name:           adns
Version:        1.6.1
Release:        1.5
Summary:        Advanced Easy-to-Use Asynchronous-Capable DNS Utilities
License:        GPL-2.0-or-later
Group:          Productivity/Networking/DNS/Utilities
URL:            https://www.chiark.greenend.org.uk/~ian/adns/ftp/
Source0:        http://www.chiark.greenend.org.uk/~ian/adns/ftp/%{name}-%{version}.tar.gz
Source1:        http://www.chiark.greenend.org.uk/~ian/adns/ftp/%{name}-%{version}.tar.gz.sig
Source2:        %{name}.keyring
Source3:        README.SUSE
Source4:        baselibs.conf
Patch1:         adns-1.4-configure.patch
Patch2:         adns-visibility.patch
BuildRequires:  autoconf

%description
adns includes a collection of useful DNS resolver utilities.

%package -n %{lname}
Summary:        Advanced DNS resolver client library
Group:          System/Libraries
Provides:       libadns = %{version}
#openSUSE 10.2
Obsoletes:      libadns <= 1.3

%description -n %{lname}
Libadns is an advanced, easy to use, asynchronous-capable DNS resolver
client library for C (and C++) programs.

%package -n libadns-devel
Summary:        Libraries and header files to develop programs with libadns support
Group:          Development/Languages/C and C++
Requires:       %{lname} = %{version}
Requires:       glibc-devel

%description -n libadns-devel
Libadns-devel includes the header file and static library to develop
programs with libads support.

%prep
%autosetup -p0
cp %{SOURCE3} .

%build
autoreconf -fiv
%configure
%make_build

%install
make install \
    prefix=%{buildroot}%{_prefix} \
    bindir=%{buildroot}%{_bindir} \
    includedir=%{buildroot}%{_includedir} \
    libdir=%{buildroot}%{_libdir} \

# FIXME: --disable-static not available
rm %{buildroot}%{_libdir}/*.a

%ldconfig_scriptlets -n %{lname}

%check
## Fails without network
#%%make_build check

%files
%license COPYING
%doc GPL-vs-LGPL README* TODO changelog
%{_bindir}/adns*

%files -n %{lname}
%license COPYING
%{_libdir}/libadns.so.1*

%files -n libadns-devel
%license COPYING
%{_includedir}/adns.h
%{_libdir}/libadns.so

%changelog
* Sat May 25 2024 Andreas Stieger <andreas.stieger@gmx.de>
- fix Factory submission and spec file tweaks
* Tue May 14 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.6.1:
  + Minor bugfix:
  * Suppress warning about `trust-ad` in resolv.conf.
  + Build system:
  * Honour DESTDIR, avoiding need for prefix= workaround.
    (Drop adns-1.4-destdir.patch)
  * regression tests: Add missing dependency on hsyscalls.i.
    GNU #51329.  [Report from Sergei Trofimovich]
  * regression tests: build with 64-bit time_t on 32-bit systems.
  + Documentation:
  * Fix all http: URLs in docs to be https: instead.
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Jun 15 2020 Kristyna Streitova <kstreitova@suse.com>
- Update to 1.6.0
- Changes in 1.6.0:
  * Bugfixes
  * adnshost: Support --reverse in -f mode input stream
  * timeout robustness against clock skew: track query start time and
    duration.  Clock instability may now only cause spurious timeouts
    rather than indefinite hangs or even assertion failures.
  * New features:
  * adnshost: Offer ability to set adns checkc flags
  * adnslogres: Honour --checkc-freq (if it comes first)
  * adnsresfilter: Honour --checkc-freq and --checkc-entex
  * time handling: Support use of CLOCK_MONOTONIC via an init flag.
  * adns_str* etc.: Improve robustness; more allowable inputs values.
  * Internal changes:
  * adnshost: adh-opts.c: Whitespace adjustments to option table
  * Build system and tests improvements
- Changes in 1.5.2
  * Important security fixes:
    CVE-2017-9103 CVE-2017-9104 CVE-2017-9105 CVE-2017-9109:
    Vulnerable applications: all adns callers.
    Exploitable by: the local recursive resolver.
    Likely worst case: Remote code execution.
    CVE-2017-9106:
    Vulnerable applications: those that make SOA queries.
    Exploitable by: upstream DNS data sources.
    Likely worst case: DoS (crash of the adns-using application)
    CVE-2017-9107:
    Vulnerable applications: those that use adns_qf_quoteok_query.
    Exploitable by: sources of query domain names.
    Likely worst case: DoS (crash of the adns-using application)
    CVE-2017-9108:
    Vulnerable applications: adnshost.
    Exploitable by: code responsible for framing the input.
    Likely worst case: DoS (adnshost crashes at EOF).
  * Bugfixes:
  * Do not include spurious external symbol `data' (fixes GCC10 build).
  * If server sends TC flag over TCP, bail rather than retrying.
  * Do not crash on certain strange resolv.conf contents.
  * Fix various crashes if a global system failure occurs, or
    adns_finish is called with outstanding queries.
  * Correct a parsing error message very slightly.
  * DNS packet parsing: Slight fix when packet is truncated.
  * Fix ABI compatibility in string conversion of certain RR types.
  * internal.h: Use `unsigned' for nextid; fixes theoretical C UB.
  * Portability fix:
  * common.make.in: add -Wno-unused-value.  Fixes build with GCC9.
  * Internal changes:
  * Additional comments describing some internal code restrions.
  * Robustness assert() against malfunctioning write() system call.
- It fixes the following CVEs [bsc#1172265]
  CVE-2017-9103, CVE-2017-9104, CVE-2017-9105, CVE-2017-9106,
  CVE-2017-9107, CVE-2017-9108, CVE-2017-9109
- refresh adns-visibility.patch
- drop adns-1.5.1-gcc10.patch that is no longer needed
* Tue Jun  2 2020 Kristyna Streitova <kstreitova@suse.com>
- add adns-1.5.1-gcc10.patch to fix build with GCC10
- run spec-cleaner
* Sat Nov  4 2017 aavindraa@gmail.com
- Update to 1.5.1
  * Fix addr queries (including subqueries, ie including deferencing MX
    lookups etc.) not to crash when one of the address queries returns
    tempfail.  Also, do not return a spurious pointer to the application
    when one of the address queries returns a permanent error (although,
    the application almost certainly won't use this pointer because the
    associated count is zero).
  * Portability fix for systems where socklen_t is bigger than int.
  * Fix for malicious optimisation of memcpy in test suite, which
    causes failure with gcc-4.1.9 -O3.
  * Fix TCP async connect handling. The bug is hidden on Linux and on most
    systems where the nameserver is on localhost. If it is not hidden,
    adns's TCP support is broken unless adns_if_noautosys is used.
  * adnsresfilter: Fix addrtextbuf buffer size.  This is not actually a
    problem in real compiled code but should be corrected.
  * Properly include harness.h in adnstest.c in regress/.  Suppresses
    a couple of compiler warnings (implicit declaration of Texit, etc.)
- cleanup with spec-cleaner
* Thu Mar 23 2017 kstreitova@suse.com
- cleanup with spec-cleaner
- get rid of %%{name} macro in the patch name
- restart patch numbering
* Mon Mar  2 2015 mpluskal@suse.com
- Remove obsolete patches
  * adns-ocloexec.patch
  * adns-1.4-ipv6.patch
- Add gpg signature
- Cleanup spec-file with spec-cleaner
- Remove already disabled %%check section, tests require working
  network setup
- Update to 1.5.0
  * This release provides full IPv6 support.  Applications can
    request AAAA records (containing IPv6 addresses) as well as,
    or instead of, A records (containing IPv4 addresses).  adns
    1.5 can speak to nameservers over IPv6.
  * converting between addresses and address literals.  These carry
    less baggage than getaddrinfo and getnameinfo.
  * bugfixes and other minor changes (see changelog for details)
* Tue Jun 11 2013 crrodriguez@opensuse.org
- remove debug statement in the spec file, leftover from
  previous change.
* Mon Jun 10 2013 crrodriguez@opensuse.org
- Build with large file support in 32 bit archs, autoconf
  stuff is fine, but C files included config.h after C library
  headers, therefore no prototypes for *64 functions found.
* Wed Mar 20 2013 mmeister@suse.com
- Added download url as source.
  Please see http://en.opensuse.org/SourceUrls
* Tue Dec 20 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Tue Nov 22 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Tue Nov 22 2011 crrodriguez@opensuse.org
- Use O_CLOEXEC in library code.
- Change the visibility patch to not use the error prone
  version-script but rather GCC visibility
* Fri Sep 16 2011 jengelh@medozas.de
- Implement baselibs for package
- Remove redundant tags/sections from specfile
* Sun Dec 19 2010 cristian.rodriguez@opensuse.org
- Use 64bit file offsets
* Fri Nov  5 2010 cristian.rodriguez@opensuse.org
- export only public symbols
* Fri Jan 16 2009 crrodriguez@suse.de
- remove static libraries
* Thu Sep 18 2008 prusnak@suse.cz
- document CVE-2008-1447 / CVE-2008-4100 poisoning vulnerability
  in README.SUSE [bnc#426515]
* Wed Feb 20 2008 prusnak@suse.cz
- added patch to support IPv6 protocol [#350506]
* Tue Aug  7 2007 crrodriguez@suse.de
- update to version 1.4
- run ldconfig
- use library packaging policy
- run make check
* Fri Sep  1 2006 mt@suse.de
- updated to adns-1.3, providing new support for SRV RRs
  and unknown RRs as well as several portability fixes.
- adopted configure and destdir patches, removed obsolete
  codecleanup and missing_symlink patches
* Wed Apr 26 2006 mrueckert@suse.de
- added adns-missing_symlink.diff:
  add missing symlink "libadns.so" so you can dynamically
  link against libadns.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 ro@suse.de
- added libadns.so.1 to filelist
* Mon Apr  4 2005 pth@suse.de
- Make declarations of adns__parse_domain match.
* Tue Aug 10 2004 lmuelle@suse.de
- Inital SuSE RPM; [#43590].
